| Title: | Eye Movement Analysis Package for Fixation and Saccade Detection |
|---|---|
| Description: | Fixation and saccade detection in eye movement recordings. This package implements a dispersion-based algorithm (I-DT) proposed by Salvucci & Goldberg (2000) which detects fixation duration and position. |
| Authors: | Simon Schwab <[email protected]> |
| Maintainer: | Simon Schwab <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.1 |
| Built: | 2026-06-09 07:30:15 UTC |
| Source: | https://github.com/schw4b/emov |
Angular size of stimulus.
emov.angdia(stimsize, distance)emov.angdia(stimsize, distance)
stimsize |
Size of the stimulus. |
distance |
Viewing distance from stimulus. |
Angular size in degrees.
Convert Cartesian to Spherical coordinates.
emov.cart2sphere(x, y, z)emov.cart2sphere(x, y, z)
x |
x. |
y |
y. |
z |
z. |
Two angles (radians) and radius
data = emov.cart2sphere(3, 4, 5)data = emov.cart2sphere(3, 4, 5)
Velocity threshold filter.
emov.filter(x, y, threshold)emov.filter(x, y, threshold)
x |
Eye position. |
y |
Eye position. |
threshold |
Velocity threshold. |
Filtered data.
I-DT algorithm.
emov.idt(t, x, y, dispersion, duration)emov.idt(t, x, y, dispersion, duration)
t |
Vector of timepoints. |
x |
horizontal eye positions. |
y |
vertical eye positions. |
dispersion |
Maximal dispersion allowed (in units of x and y). |
duration |
Minimal fixation duration allowed (in number of samples) |
Fixations: position, start, end.
Salvucci, D. D., & Goldberg, J. H. (2000). Identifying fixations and saccades in eye-tracking protocols. In Proceedings of the 2000 symposium on eye tracking research & applications (pp. 71-78). New York: ACM.
Read SMI iview sample file.
emov.read_iviewsamples(file, nr_of_headerlines)emov.read_iviewsamples(file, nr_of_headerlines)
file |
Filename. |
nr_of_headerlines |
No. of header lines in datafile. |
data file.
Five seconds of eye movement data recorded with an SMI eye tracker 200 Hz
fivesecfivesec
A data.frame that contains time, x and y eye positions.
Simon Schwab